diff --git a/product/ERP5/tests/testERP5Simulation.py b/product/ERP5/tests/testERP5Simulation.py
index 2a3ad85298c13d8c225ea8a29ca926e63f2e7105..fc15c4c918919f86b971b81b7eef04bcd39b1e23 100644
--- a/product/ERP5/tests/testERP5Simulation.py
+++ b/product/ERP5/tests/testERP5Simulation.py
@@ -79,11 +79,11 @@ class TestERP5Simulation(TestERP5SimulationMixin, ERP5TypeTestCase):
           tested_property=i,
           divergence_provider=0,
           matching_provider=1)
-      # create float divergence testers
-      for i in ('converted_quantity',):
+      # create net converted quantity divergence testers
+      for i in ('quantity',):
         new_order_rule.newContent(
           title='%s divergence tester' % i,
-          portal_type='Float Divergence Tester',
+          portal_type='Net Converted Quantity Divergence Tester',
           tested_property=i,
           use_delivery_ratio=1,
           quantity_range_min=-1,
@@ -125,7 +125,7 @@ class TestERP5Simulation(TestERP5SimulationMixin, ERP5TypeTestCase):
     solver_process = solver_tool.newSolverProcess(packing_list)
     sequence.edit(solver_process=solver_process)
     quantity_solver_decision = filter(
-      lambda x:x.getCausalityValue().getTestedProperty()=='converted_quantity',
+      lambda x:x.getCausalityValue().getTestedProperty()=='quantity',
       solver_process.contentValues())[0]
     # use Quantity Split Solver.
     quantity_solver_decision.setSolverValue(self.portal.portal_types['Quantity Split Solver'])
@@ -288,11 +288,11 @@ class TestERP5SimulationPackingList(TestERP5SimulationMixin, TestPackingList):
           portal_type='DateTime Divergence Tester',
           tested_property=i,
           quantity=0)
       # create float divergence testers
       for i in ('quantity',):
         new_order_rule.newContent(
           title='%s divergence tester' % i,
-          portal_type='Float Divergence Tester', # XXX-JPS Quantity Divergence Tester ? (ie. quantity unit)
+          portal_type='Net Converted Quantity Divergence Tester',
           tested_property=i,
           use_delivery_ratio=1,
           quantity=0)
@@ -288,11 +288,11 @@ class TestERP5SimulationPackingList(TestERP5SimulationMixin, TestPackingList):
           tested_property=i,
           quantity=0)
-      # create float divergence testers
+      # create net converted quantity divergence testers
       for i in ('quantity',):
         new_order_rule.newContent(